/*
 * Project: MoleCuilder
 * Description: creates and alters molecular systems
 * Copyright (C)  2012 University of Bonn. All rights reserved.
 * Please see the LICENSE file or "Copyright notice" in builder.cpp for details.
 */

/*
 * KeyValueValidator.cpp
 *
 *  Created on: May 14, 2012
 *      Author: ankele
 */


// include config.h
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "CodePatterns/MemDebug.hpp"

#include "KeyValueValidator.hpp"

bool KeyValueValidator::isValid(const std::string & _value) const
{
  size_t keyvaluestart = 0;
  size_t keyvalueend = _value.length()-1;
  do {
    size_t keyvaluemid = _value.find("=", keyvaluestart);
    if (keyvaluemid == std::string::npos)
      // No "=" found.
      return false;

    if (keyvaluemid == keyvaluestart)
      // Nothing before "=".
      return false;

    if (keyvaluemid == keyvalueend)
      // Nothing after "=".
      return false;

    keyvalueend = keyvaluestart;
    keyvaluestart = _value.find(";", keyvaluestart+1);
    // allow ending semicolon
    if (keyvaluestart == _value.length()-1)
      keyvaluestart = std::string::npos;
  } while (keyvaluestart != std::string::npos);

  return true;
}

bool KeyValueValidator::operator==(const Validator<std::string> &_instance) const
{
  const KeyValueValidator *inst =
      dynamic_cast<const KeyValueValidator *>(&_instance);
  if (inst)
    return true;
  else
    return false;
}

Validator< std::string >* KeyValueValidator::clone() const
{
  Validator< std::string > *inst =
      new KeyValueValidator();
  return inst;
}




